Index: board/integratorap/integratorap.c
===================================================================
RCS file: /cvsroot/u-boot/u-boot/board/integratorap/integratorap.c,v
retrieving revision 1.4
diff -u -b -p -r1.4 integratorap.c
--- board/integratorap/integratorap.c	10 Oct 2004 18:41:07 -0000	1.4
+++ board/integratorap/integratorap.c	12 Jan 2005 13:21:30 -0000
@@ -14,6 +14,10 @@
  * ARM Ltd.
  * Philippe Robin, <philippe.robin@arm.com>
  *
+ * (C) Copyright 2005
+ * Koninklijke Philips Electronics NV
+ * Jean-Paul Saman <jean-paul.saman@philips.com>
+ *
  * See file CREDITS for list of people who contributed to this
  * project.
  *
@@ -41,6 +45,7 @@
 
 void flash__init (void);
 void ether__init (void);
+int dram_init (void);
 void peripheral_power_enable (void);
 
 #if defined(CONFIG_SHOW_BOOT_PROGRESS)
@@ -78,6 +83,7 @@ int board_init (void)
 	icache_enable ();
 
 	flash__init ();
+	dram_init ();
 	return 0;
 }
 
@@ -460,6 +466,7 @@ void pci_init_board (void)
 void flash__init (void)
 {
 }
+
 /*************************************************************
  Routine:ether__init
  Description: take the Ethernet controller out of reset and wait
@@ -470,10 +477,19 @@ void ether__init (void)
 }
 
 /******************************
- Routine:
- Description:
+ Routine: dram_init
+ Description: remap SDRAM to the memory base address
+                       and enable the LED on the integrator board.
 ******************************/
 int dram_init (void)
 {
+#if defined(INTEGRATOR_CM_REMAP)
+        if ( (((volatile unsigned char*)(CM_CTL))[0] & 0x02) == 0 )
+        {
+                /* Core Module is mounted on INTEGRATOR motherboard */
+                ((volatile unsigned char*)(CM_CTL))[0] |= (CM_CTL_REMAP_ENABLE);
+                ((volatile unsigned char*)(CM_CTL))[0] |= (CM_CTL_REMAP_LED_ON);
+        }
+#endif
 	return 0;
 }
Index: include/configs/integratorap.h
===================================================================
RCS file: /cvsroot/u-boot/u-boot/include/configs/integratorap.h,v
retrieving revision 1.3
diff -u -b -p -r1.3 integratorap.h
--- include/configs/integratorap.h	2 Aug 2004 23:23:00 -0000	1.3
+++ include/configs/integratorap.h	12 Jan 2005 13:21:30 -0000
@@ -39,7 +39,6 @@
 #define CONFIG_INTEGRATOR	1	/* in an Integrator board	*/
 #define CONFIG_ARCH_CINTEGRATOR 1	/* Specifically, a CP		*/
 
-
 #define CFG_MEMTEST_START   0x100000
 #define CFG_MEMTEST_END   0x10000000
 #define CFG_HZ	(1000000 / 256)		/* Timer 1 is clocked at 1Mhz, with 256 divider */
@@ -57,7 +56,7 @@
 /*
  * PL010 Configuration
  */
-#define CFG_PL010_SERIAL
+#define CFG_PL010_SERIAL	1
 #define CONFIG_CONS_INDEX	0
 #define CONFIG_BAUDRATE         38400
 #define CONFIG_PL01x_PORTS	{ (void *) (CFG_SERIAL0), (void *) (CFG_SERIAL1) }
@@ -114,6 +113,18 @@
 #define CFG_FLASH_BASE          0x24000000
 
 /*-----------------------------------------------------------------------
+ * Core Module Control Register
+ */
+#define INTEGRATOR_CM_REMAP  1  /* Remap SSRAM to 0x00000000 when MBDET=1 */
+
+#define CM_ID_BASE           0x10000000 /* Core Module base address */
+#define CM_CTL               (CM_ID_BASE+0x0000000C) /* Control register */
+#define CM_CTL_RESET         0x08 /* Core Module reset */
+#define CM_CTL_REMAP_ENABLE  0x04 /* Enable remap of SSRAM to base address */
+#define CM_CTL_MBDET         0x02 /* =0 if CM is mounted on motherboard, =1 standalone */
+#define CM_CTL_REMAP_LED_ON  0x01 /* Enable LED when SSRAM is remapped */
+
+/*-----------------------------------------------------------------------
  * FLASH and environment organization
  */
 #define CFG_ENV_IS_NOWHERE
@@ -131,8 +142,8 @@
  * PCI definitions
  */
 
-/*#define CONFIG_PCI			/--* include pci support			*/
-#undef CONFIG_PCI_PNP
+#define CONFIG_PCI		1	/* include pci support		*/
+#define CONFIG_PCI_PNP  1
 #define CONFIG_PCI_SCAN_SHOW    1       /* show pci devices on startup  */
 #define DEBUG
 
